#ifndef REPARMA_H
#define REPARMA_H

#include "config.h"
#include <algorithm>
arma::vec reparma(const arma::vec& x, const arma::uvec& y);

#endif
